pub enum AccountAddress {
Pubkey(String),
Pda {
program_id: String,
seeds: Vec<PdaSeed>,
},
}Expand description
Defines how an account address should be determined Defines how an account address should be determined
Variants
Pubkey(String)
A specific public key A specific public key
Pda
A Program Derived Address with seeds A Program Derived Address with seeds