pub struct FifoMap<K, V> { /* private fields */ }Implementations
Sourceimpl<K: Hash + Eq, V> FifoMap<K, V>
impl<K: Hash + Eq, V> FifoMap<K, V>
pub fn new(capacity: usize) -> Self
pub fn capacity(&self) -> usize
pub fn len(&self) -> usize
pub fn clear(&mut self)
pub fn is_empty(&self) -> bool
Sourcepub fn insert(&mut self, key: K, value: V) -> (Option<V>, Option<K>)
pub fn insert(&mut self, key: K, value: V) -> (Option<V>, Option<K>)
Insert a key/value. If K is new and we’re full, evict the oldest (FIFO)
Returns a tuple of (old_value, evicted_key):
- old_value: The previous value if this was an update to an existing key
- evicted_key: The key that was evicted if the map was at capacity
pub fn get(&self, key: &K) -> Option<&V>
pub fn get_mut(&mut self, key: &K) -> Option<&mut V>
pub fn contains_key(&self, key: &K) -> bool
Sourcepub fn remove(&mut self, key: &K) -> Option<V>
pub fn remove(&mut self, key: &K) -> Option<V>
Removes a key from the map, returning the value if present.
pub fn iter(&self) -> impl ExactSizeIterator<Item = (&K, &V)>