pub struct SimnetConfig {Show 14 fields
pub offline_mode: bool,
pub remote_rpc_url: Option<String>,
pub slot_time: u64,
pub block_production_mode: BlockProductionMode,
pub airdrop_addresses: Vec<Pubkey>,
pub airdrop_token_amount: u64,
pub expiry: Option<u64>,
pub instruction_profiling_enabled: bool,
pub max_profiles: usize,
pub log_bytes_limit: Option<usize>,
pub feature_config: SvmFeatureConfig,
pub skip_signature_verification: bool,
pub surfnet_id: String,
pub snapshot: BTreeMap<String, Option<AccountSnapshot>>,
}Fields
offline_mode: boolremote_rpc_url: Option<String>slot_time: u64block_production_mode: BlockProductionModeairdrop_addresses: Vec<Pubkey>airdrop_token_amount: u64expiry: Option<u64>instruction_profiling_enabled: boolmax_profiles: usizelog_bytes_limit: Option<usize>feature_config: SvmFeatureConfigskip_signature_verification: boolsurfnet_id: StringUnique identifier for this surfnet instance. Used to isolate database storage when multiple surfnets share the same database. Defaults to “default”.
snapshot: BTreeMap<String, Option<AccountSnapshot>>Snapshot accounts to preload at startup. Keys are pubkey strings, values can be None to fetch from remote RPC.
Implementations
Sourceimpl SimnetConfig
impl SimnetConfig
Sourcepub fn get_sanitized_datasource_url(&self) -> Option<String>
pub fn get_sanitized_datasource_url(&self) -> Option<String>
Returns a sanitized version of the datasource URL safe for display. Only returns scheme and host (e.g., “https://example.com”) to prevent leaking API keys in paths or query parameters.