pub struct TokenAccountUpdate {
pub amount: Option<u64>,
pub delegate: Option<SetSomeAccount>,
pub state: Option<String>,
pub delegated_amount: Option<u64>,
pub close_authority: Option<SetSomeAccount>,
}Fields
amount: Option<u64>providing this value sets the amount of the token in the account data
delegate: Option<SetSomeAccount>providing this value sets the delegate of the token account
state: Option<String>providing this value sets the state of the token account
delegated_amount: Option<u64>providing this value sets the amount authorized to the delegate
providing this value sets the close authority of the token account