AccountAddress

Enum AccountAddress 

pub enum AccountAddress {
    Pubkey(String),
    Pda {
        program_id: String,
        seeds: Vec<PdaSeed>,
    },
}
Defines how an account address should be determined Defines how an account address should be determined

Variants



Pubkey(String)

A specific public key A specific public key



Pda

A Program Derived Address with seeds A Program Derived Address with seeds

Fields

program_id: String
seeds: Vec<PdaSeed>

Implementations

Source

impl AccountAddress

pub fn resolve(&self, values: Option<&HashMap<String, Value>>) -> Option<Pubkey>

Resolve the account address to a Pubkey For PDA addresses, this derives the address from the program_id and seeds For PropertyRef seeds, values map is used to resolve the reference

pub fn resolve_simple(&self) -> Option<Pubkey>

Resolve the account address to a Pubkey without any values for PropertyRef This is a convenience method when no PropertyRef seeds are expected

pub fn get_pda_seed_references(&self) -> Vec<String>

Get the names of values that are referenced by PDA seeds These should be filtered out when applying account data overrides since they’re only used for address derivation, not account data modification