pub struct OverrideInstance {
pub id: String,
pub template_id: String,
pub values: HashMap<String, Value>,
pub scenario_relative_slot: Slot,
pub label: Option<String>,
pub enabled: bool,
pub fetch_before_use: bool,
pub account: AccountAddress,
}Expand description
A concrete instance of an override template with specific values
Fields
id: StringUnique identifier for this instance Unique identifier for the scenario
template_id: StringReference to the template being used Reference to the template being used
values: HashMap<String, Value>Values for the template properties (flat key-value map with dot notation, e.g., “price_message.price_value”) Values for the template properties (flat key-value map with dot notation, e.g., ‘price_message.price_value’)
scenario_relative_slot: SlotRelative slot when this override should be applied (relative to scenario registration slot) Relative slot when this override should be applied (relative to scenario registration slot)
label: Option<String>Optional label for this instance Optional label for this instance
enabled: boolWhether this override is enabled Whether this override is enabled
fetch_before_use: boolWhether to fetch fresh account data just before transaction execution Whether to fetch fresh account data just before transaction execution
account: AccountAddressAccount address to override Account address to override
Implementations
Sourceimpl OverrideInstance
impl OverrideInstance
pub fn new( template_id: String, scenario_relative_slot: Slot, account: AccountAddress, ) -> Self
pub fn with_values(self, values: HashMap<String, Value>) -> Self
pub fn with_label(self, label: String) -> Self